@@ -1,6 +1,9 @@
+import asyncio
 import logging
 import logging.handlers
 
+import aiohttp
+
 from .endpoints.app import App
 from .endpoints.base import Base
 from .endpoints.community_content import CommunityContent
@@ -54,6 +57,7 @@ class DestinyClient():
         max_ratelimit_retries: int = 3,
         log_file: str = "logs/destipy.log",
         logger = None,
+        loop = None
     ) -> None:
 
         default_logger = logging.getLogger("Destipy")
@@ -69,7 +73,9 @@ class DestinyClient():
             default_logger.handlers.clear()
         default_logger.addHandler(file_handler)
         self.logger = default_logger if logger is None else logger
-        requester = Requester(api_key, max_ratelimit_retries, self.logger)
+        self._loop = asyncio.get_event_loop() if loop is None else loop
+        self._session = aiohttp.ClientSession(loop=self._loop)
+        requester = Requester(api_key, max_ratelimit_retries, self.logger, self._session)
         self.app: App = App(client_id, requester, self.logger)
         self.base: Base = Base(requester, self.logger)
         self.community_content: CommunityContent = CommunityContent(requester, self.logger)
@@ -78,7 +84,7 @@ class DestinyClient():
         self.fireteam: Fireteam = Fireteam(requester, self.logger)
         self.forum: Forum = Forum(requester, self.logger)
         self.group_v2: GroupV2 = GroupV2(requester, self.logger)
-        self.manifest: Manifest = Manifest(self.destiny2)
+        self.manifest: Manifest = Manifest(self.destiny2, self._session)
         self.oauth: OAuth = OAuth(client_id, client_secret, requester, redirect_uri, self.logger)
         self.social: Social = Social(requester, self.logger)
         self.tokens: Tokens = Tokens(requester, self.logger)
