@@ -18,11 +18,12 @@ class Requester:
         api_key: str,
         max_ratelimit_retries: int,
         logger: logging.Logger,
+        session: aiohttp.ClientSession,
     ) -> None:
         self.api_key = api_key
         self.logger = logger
         self.max_ratelimit_retries = max_ratelimit_retries
-
+        self.session = session
     async def handle_ratelimit(
         self,
         response: aiohttp.ClientResponse,
@@ -89,7 +90,7 @@ class Requester:
             else:
                 kwargs["json"] = data
 
-        async with aiohttp.ClientSession() as session:
+        async with self.session as session:
             taken_time = time.monotonic()
             # Make the request using the ClientSession.request method
             async with session.request(method.value, url, headers=headers, **kwargs) as response:
@@ -104,4 +105,4 @@ class Requester:
                     return {}
                 # Return the response as a json. Provide the user the ability to handle the status code
                 return await response.json()
-             
\ No newline at end of file
+        
\ No newline at end of file
